<?php

declare(strict_types=1);

namespace Smile\RetailerOffer\Ui\Component\Offer\Form\Retailer;

use Magento\Framework\App\RequestInterface;
use Magento\Framework\Data\OptionSourceInterface;
use Smile\Retailer\Model\ResourceModel\Retailer\Collection as RetailerCollection;

/**
 * Source Model for Retailer Picker.
 */
class Options implements OptionSourceInterface
{
    protected ?array $retailersList = null;

    public function __construct(
        protected RetailerCollection $retailerCollection,
        protected RequestInterface $request
    ) {
    }

    /**
     * @inheritdoc
     */
    public function toOptionArray(): array
    {
        return $this->getRetailerList();
    }

    /**
     * Retrieve retailer tree.
     */
    protected function getRetailerList(): array
    {
        if ($this->retailersList === null) {
            $this->retailersList = [];
            $storeId = $this->request->getParam('store');

            $this->retailerCollection
                ->addAttributeToSelect(['name', 'is_active'])
                ->setStoreId($storeId);

            foreach ($this->retailerCollection as $retailer) {
                $this->retailersList[$retailer->getId()] = [
                    'value'     => $retailer->getId(),
                    'is_active' => $retailer->getIsActive(),
                    'label'     => $retailer->getName(),
                ];
            }
        }

        return $this->retailersList;
    }
}
